DefaultParamEditorAddon class
final
- Inheritance
-
- Mixed-in types
-
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
decode(dynamic state)
→ void
-
Read state from json-like object
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
encode()
→ dynamic
-
Serialize state to json encodable object
inherited
-
encodeWithDifference()
→ dynamic
-
Encode state and return difference from initial state.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited