build method

  1. @override
TreeType<NodeData> build()

Initialize a Notifier.

It is safe to use Ref.watch or Ref.listen inside this method.

If a dependency of this Notifier (when using Ref.watch) changes, then build will be re-executed. On the other hand, the Notifier will not be recreated. Its instance will be preserved between executions of build.

If this method throws, reading this provider will rethrow the error.

Implementation

@override
TreeType<NodeData> build() {
  final components = ref.watch(componentsProvider);
  return parse(components);
}