build method

  1. @override
Future<String?> build()

Initialize an AsyncNotifier.

It is safe to use Ref.watch or Ref.listen inside this method.

If a dependency of this AsyncNotifier (when using Ref.watch) changes, then build will be re-executed. On the other hand, the AsyncNotifier will not be recreated. Its instance will be preserved between executions of build.

If this method throws or returns a future that fails, the error will be caught and an AsyncError will be emitted.

Implementation

@override
Future<String?> build() async {
  _preferences = await ref.watch(sharedPreferencesProvider.future);
  final value = _preferences.getString('path');

  _completer.complete(Future.microtask(() {}));

  return value;
}